@@ -1,4 +1,4 @@
-test_that("multiplication works", {
+test_that("read ATE data sets", {
   fileName <- ATE.sampleFiles('_Complete_')
   d1 <- ATE.complete(fileName, TRUE)
   expect_equal(nrow(d1),1)
